@@ -251,7 +251,11 @@ bool VlcMediaWidget::init()
 	QStringList argList;
 	int argc = 0, size;
 
+#if QT_VERSION < 0x050e00
 	argList = args.split(' ', QString::SkipEmptyParts);
+#else
+	argList = args.split(' ', Qt::SkipEmptyParts);
+#endif
 	size = argList.size();
 
 	const char **argv = new const char *[size];
@@ -339,13 +343,13 @@ VlcMediaWidget::~VlcMediaWidget()
 
 VlcMediaWidget *VlcMediaWidget::createVlcMediaWidget(QWidget *parent)
 {
-	QScopedPointer<VlcMediaWidget> vlcMediaWidget(new VlcMediaWidget(parent));
+	std::unique_ptr<VlcMediaWidget> vlcMediaWidget(new VlcMediaWidget(parent));
 
 	if (!vlcMediaWidget->init()) {
 		return NULL;
 	}
 
-	return vlcMediaWidget.take();
+	return vlcMediaWidget.release();
 }
 
 QStringList VlcMediaWidget::getAudioDevices()
@@ -910,7 +914,7 @@ void VlcMediaWidget::updateMetadata()
 
 	if (urlIsAudioCd)
 		metadata.insert(MediaWidget::Title,
-				i18n("CD track ") + QString::number(trackNumber));
+				i18n("CD track %1", QString::number(trackNumber)));
 }
 
 void VlcMediaWidget::updateAudioStreams()
@@ -1073,7 +1077,7 @@ void VlcMediaWidget::mouseMoveEvent(QMouseEvent *event)
 
 void VlcMediaWidget::vlcEvent(const libvlc_event_t *event)
 {
-	PendingUpdates pendingUpdatesToBeAdded = 0;
+	PendingUpdates pendingUpdatesToBeAdded = Nothing;
 
 	switch (event->type) {
 #if LIBVLC_VERSION_MAJOR > 2
@@ -1116,3 +1120,5 @@ void VlcMediaWidget::vlcEventHandler(const libvlc_event_t *event, void *instance
 {
 	reinterpret_cast<VlcMediaWidget *>(instance)->vlcEvent(event);
 }
+
+#include "moc_vlcmediawidget.cpp"
