@@ -51,6 +51,14 @@ Configuration::~Configuration()
 {
 }
 
+void Configuration::detach()
+{
+	if (globalInstance) {
+		delete globalInstance;
+		globalInstance = NULL;
+	}
+}
+
 Configuration *Configuration::instance()
 {
 	if (globalInstance == NULL) {
@@ -93,3 +101,5 @@ void Configuration::setLibVlcArguments(QString newArguments)
 }
 
 Configuration *Configuration::globalInstance = NULL;
+
+#include "moc_configuration.cpp"
