@@ -37,6 +37,7 @@
 #include "dvbchanneldialog.h"
 #include "dvbchanneldialog_p.h"
 #include "dvbsi.h"
+#include "../iso-codes.h"
 
 bool DvbChannelLessThan::operator()(const DvbSharedChannel &x, const DvbSharedChannel &y) const
 {
@@ -322,6 +323,11 @@ void DvbChannelView::checkChannelDragAndDrop(bool *ok)
 	}
 }
 
+void DvbChannelView::channelPidsChanged(const DvbSharedChannel &channel)
+{
+	emit channelPidsUpdated(channel);
+}
+
 void DvbChannelView::editChannel()
 {
 	QModelIndex index = currentIndex();
@@ -330,6 +336,8 @@ void DvbChannelView::editChannel()
 		QDialog *dialog = new DvbChannelEditor(tableModel, tableModel->value(index), this);
 		dialog->setAttribute(Qt::WA_DeleteOnClose, true);
 		dialog->setModal(true);
+		connect(dialog, SIGNAL(channelPidsChanged(DvbSharedChannel)),
+			this, SLOT(channelPidsChanged(DvbSharedChannel)));
 		dialog->show();
 	}
 }
@@ -704,6 +712,8 @@ DvbChannelEditor::DvbChannelEditor(DvbChannelTableModel *model_, const DvbShared
 	QBoxLayout *mainLayout = new QVBoxLayout(widget);
 	QGridLayout *gridLayout = new QGridLayout();
 
+	audioStreamBox = NULL;
+
 	nameEdit = new QLineEdit(widget);
 	nameEdit->setText(channel->name);
 	gridLayout->addWidget(nameEdit, 0, 1);
@@ -921,13 +931,45 @@ DvbChannelEditor::DvbChannelEditor(DvbChannelTableModel *model_, const DvbShared
 	serviceIdBox->setValue(channel->serviceId);
 	gridLayout->addWidget(serviceIdBox, row++, 1);
 
+	DvbPmtSection pmtSection(channel->pmtSectionData);
+	DvbPmtParser pmtParser(pmtSection);
+
 	gridLayout->addWidget(new QLabel(i18n("Audio channel:")), row, 0);
-	audioStreamBox = new QComboBox(groupBox);
-	audioStreamBox->setCurrentIndex(audioPids.indexOf(channel->audioPid));
-	if (audioPids.size() <= 1) {
-		audioStreamBox->setEnabled(false);
+	if (pmtParser.audioPids.count() > 1) {
+		audioStreamBox = new QComboBox(groupBox);
+
+		for (int i = 0; i < pmtParser.audioPids.size(); ++i) {
+			const QPair<int, QString> &it = pmtParser.audioPids.at(i);
+			QString text = QString::number(it.first);
+
+			if (!it.second.isEmpty()) {
+				QString languageString;
+
+				if (!IsoCodes::getLanguage(it.second, &languageString))
+					languageString = it.second;
+
+				text = text + QLatin1String(" (") + languageString + QLatin1Char(')');
+			}
+
+			audioStreamBox->addItem(text);
+			audioPids.append(it.first);
+		}
+		audioStreamBox->setCurrentIndex(audioPids.indexOf(channel->audioPid));
+		gridLayout->addWidget(audioStreamBox, row++, 1);
+	} else {
+		const QPair<int, QString> &it = pmtParser.audioPids.at(0);
+		QString text = QString::number(it.first);
+
+		if (!it.second.isEmpty()) {
+			QString languageString;
+
+			if (!IsoCodes::getLanguage(it.second, &languageString))
+				languageString = it.second;
+
+			text = text + QLatin1String(" (") + languageString + QLatin1Char(')');
+		}
+		gridLayout->addWidget(new QLabel(text), row++, 1);
 	}
-	gridLayout->addWidget(audioStreamBox, row++, 1);
 
 	gridLayout->addWidget(new QLabel(i18n("Scrambled:")), row, 0);
 	scrambledBox = new QCheckBox(groupBox);
@@ -939,21 +981,6 @@ DvbChannelEditor::DvbChannelEditor(DvbChannelTableModel *model_, const DvbShared
 	gridLayout->addWidget(new QLabel(i18n("PMT PID:")), row, 0);
 	gridLayout->addWidget(new QLabel(QString::number(channel->pmtPid)), row++, 1);
 
-	DvbPmtSection pmtSection(channel->pmtSectionData);
-	DvbPmtParser pmtParser(pmtSection);
-
-	for (int i = 0; i < pmtParser.audioPids.size(); ++i) {
-		const QPair<int, QString> &it = pmtParser.audioPids.at(i);
-		QString text = QString::number(it.first);
-
-		if (!it.second.isEmpty()) {
-			text = text + QLatin1String(" (") + it.second + QLatin1Char(')');
-		}
-
-		audioStreamBox->addItem(text);
-		audioPids.append(it.first);
-	}
-
 	if (pmtParser.videoPid >= 0) {
 		gridLayout->addWidget(new QLabel(i18n("Video PID:")), row, 0);
 		gridLayout->addWidget(new QLabel(QString::number(pmtParser.videoPid)), row++, 1);
@@ -965,7 +992,13 @@ DvbChannelEditor::DvbChannelEditor(DvbChannelTableModel *model_, const DvbShared
 
 	for (int i = 0; i < pmtParser.subtitlePids.size(); ++i) {
 		const QPair<int, QString> &it = pmtParser.subtitlePids.at(i);
-		gridLayout->addWidget(new QLabel(QString(QLatin1String("%1 (%2)")).arg(it.first).arg(it.second)),
+		QString languageString;
+
+		if (!IsoCodes::getLanguage(it.second, &languageString))
+			languageString = it.second;
+
+
+		gridLayout->addWidget(new QLabel(QString(QLatin1String("%1 (%2)")).arg(it.first).arg(languageString)),
 			row++, 1);
 	}
 
@@ -998,17 +1031,32 @@ DvbChannelEditor::~DvbChannelEditor()
 void DvbChannelEditor::accept()
 {
 	DvbChannel updatedChannel = *channel;
+	int oldAudioPid = channel->audioPid;
+
 	updatedChannel.name = nameEdit->text();
 	updatedChannel.number = numberBox->value();
 	updatedChannel.networkId = networkIdBox->value();
 	updatedChannel.transportStreamId = transportStreamIdBox->value();
 	updatedChannel.serviceId = serviceIdBox->value();
 
-	if (audioStreamBox->currentIndex() != -1) {
+	if (audioStreamBox && audioStreamBox->currentIndex() != -1) {
 		updatedChannel.audioPid = audioPids.at(audioStreamBox->currentIndex());
 	}
 
 	updatedChannel.isScrambled = scrambledBox->isChecked();
 	model->getChannelModel()->updateChannel(channel, updatedChannel);
+
+	/*
+	 * If a channel is being played, a change at a PID should
+	 * be reflected at the played channel.
+	 *
+	 * TODO: add support for videos with multiple PIDs
+	 */
+	if (updatedChannel.audioPid != oldAudioPid)
+		emit channelPidsChanged(channel);
+
 	QDialog::accept();
 }
+
+#include "moc_dvbchanneldialog_p.cpp"
+#include "moc_dvbchanneldialog.cpp"
