@@ -95,7 +95,7 @@ private:
 	void initRegexButtons(QGridLayout *buttonGrid);
 	//void deleteChildWidgets(QLayoutItem *item);
 
-	void accept();
+	void accept() override;
 
 	DvbManager *manager;
 	QTabWidget *tabWidget;
@@ -138,6 +138,7 @@ private:
 	QByteArray scanData;
 	QVBoxLayout *mainLayout;
 	QDialogButtonBox *buttonBox;
+	QString errorMsg;
 };
 
 class DvbConfigPage : public QWidget
