@@ -72,7 +72,7 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 
 	// compatibility code
 
-	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/recordings.dvb"));
+	QFile file(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + QLatin1String("/recordings.dvb"));
 
 	if (!file.exists()) {
 		return;
@@ -287,7 +287,8 @@ void DvbRecordingModel::executeActionAfterRecording(DvbRecording recording)
 	if (!stopCommand.isEmpty())
 	{
 		QProcess* child = new QProcess();
-		child->start(stopCommand);
+		child->setProgram(stopCommand);
+		child->start();
 		qCWarning(logDvb, "Not executing command after recording");
 	}
 	qCDebug(logDvb, "executed.");
@@ -634,8 +635,8 @@ int DvbRecordingModel::getSecondsUntilNextRecording() const
 			break;
 		}
 		if (rec.begin > QDateTime::currentDateTime().toUTC()) {
-			if (timeUntil == -1 || timeUntil > rec.begin.toTime_t() - QDateTime::currentDateTime().toUTC().toTime_t()) {
-				timeUntil = rec.begin.toTime_t() - QDateTime::currentDateTime().toUTC().toTime_t();
+			if (timeUntil == -1 || timeUntil > rec.begin.toSecsSinceEpoch() - QDateTime::currentDateTime().toUTC().toSecsSinceEpoch()) {
+				timeUntil = rec.begin.toSecsSinceEpoch() - QDateTime::currentDateTime().toUTC().toSecsSinceEpoch();
 			}
 		}
 
@@ -845,6 +846,7 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 			if (file.open(QIODevice::ReadWrite))
 			{
 			    QTextStream stream(&file);
+#if QT_VERSION < 0x050e00
 			    stream << "EPG info" << endl;
 			    stream << "Title: " + QString(recording.name) << endl;
 			    stream << "Description: " + QString(recording.subheading) << endl;
@@ -853,6 +855,16 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 			    stream << "Date: " + recording.beginEPG.toLocalTime().toString("yyyy-MM-dd") << endl;
 			    stream << "Start time: " + recording.beginEPG.toLocalTime().toString("hh:mm:ss") << endl;
 			    stream << "Duration: " + recording.durationEPG.toString("HH:mm:ss") << endl;
+#else
+			    stream << "EPG info" << Qt::endl;
+			    stream << "Title: " + QString(recording.name) << Qt::endl;
+			    stream << "Description: " + QString(recording.subheading) << Qt::endl;
+			    //stream << "Details: " + QString(recording.details) << Qt::endl; // Details is almost always empty
+			    stream << "Channel: " + QString(recording.channel->name) << Qt::endl;
+			    stream << "Date: " + recording.beginEPG.toLocalTime().toString("yyyy-MM-dd") << Qt::endl;
+			    stream << "Start time: " + recording.beginEPG.toLocalTime().toString("hh:mm:ss") << Qt::endl;
+			    stream << "Duration: " + recording.durationEPG.toString("HH:mm:ss") << Qt::endl;
+#endif
 			}
 		}
 
@@ -1069,3 +1081,5 @@ void DvbRecordingFile::processData(const char data[188])
 	file.write(data, 188);
 }
 
+#include "moc_dvbrecording_p.cpp"
+#include "moc_dvbrecording.cpp"
