@@ -119,10 +119,10 @@ public:
 
 	QAbstractItemModel *createProxyModel(QObject *parent);
 
-	int columnCount(const QModelIndex &parent) const;
-	int rowCount(const QModelIndex &parent) const;
-	QVariant data(const QModelIndex &index, int role) const;
-	QVariant headerData(int section, Qt::Orientation orientation, int role) const;
+	int columnCount(const QModelIndex &parent) const override;
+	int rowCount(const QModelIndex &parent) const override;
+	QVariant data(const QModelIndex &index, int role) const override;
+	QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
 
 	void appendChannels(const QList<DvbPreviewChannel> &list)
 	{
@@ -464,7 +464,7 @@ void DvbScanDialog::scanButtonClicked(bool checked)
 			}
 		} else {
 			scanButton->setChecked(false);
-			KMessageBox::sorry(this,
+			KMessageBox::information(this,
 				i18nc("message box", "No available device found."));
 			return;
 		}
@@ -505,7 +505,7 @@ void DvbScanDialog::foundChannels(const QList<DvbPreviewChannel> &channels)
 			continue;
 		}
 
-		QStringList::const_iterator it = qLowerBound(providers.constBegin(),
+		QStringList::const_iterator it = std::lower_bound(providers.constBegin(),
 			providers.constEnd(), channel.provider, localeAwareLessThan2);
 
 		if ((it != providers.constEnd()) && (*it == channel.provider)) {
@@ -609,3 +609,5 @@ void DvbScanDialog::setDevice(DvbDevice *newDevice)
 		updateStatus();
 	}
 }
+
+#include "moc_dvbscandialog.cpp"
