@@ -153,22 +153,22 @@ public:
 	Iso6937Codec() { }
 	~Iso6937Codec() { }
 
-	QByteArray name() const
+	QByteArray name() const override
 	{
 		return "ISO 6937"; // actually a superset of ISO 6937
 	}
 
-	int mibEnum() const
+	int mibEnum() const override
 	{
 		return 14;
 	}
 
-	QByteArray convertFromUnicode(const QChar *, int, QTextCodec::ConverterState *) const
+	QByteArray convertFromUnicode(const QChar *, int, QTextCodec::ConverterState *) const override
 	{
 		return QByteArray();
 	}
 
-	QString convertToUnicode(const char *input, int size, QTextCodec::ConverterState *) const
+	QString convertToUnicode(const char *input, int size, QTextCodec::ConverterState *) const override
 	{
 		QString result;
 		unsigned short diacriticalMark = 0;
@@ -406,13 +406,13 @@ QString AtscPsipText::interpretTextData(const char *data, unsigned int len,
 	    (mode >= 0x30 && mode <= 0x33)) {
 		// Select UNICODE Code range based on mode as leading octet
 		for (unsigned int i = 0; i < len; i++) {
-			QChar val = (data[i] | (mode << 8));
+			QChar val = QChar(data[i] | (mode << 8));
 			result += val;
 		}
 	} else if (mode == 0x3f) {
 		// UTF-16
 		for (unsigned int i = 0; i < len; i += 2) {
-			QChar val = ((unsigned char)data[i] * 256) + (unsigned char)data[i+1];
+			QChar val = QChar(((unsigned char)data[i] * 256) + (unsigned char)data[i+1]);
 			result += val;
 		}
 	} else {
@@ -1159,12 +1159,37 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 	for (DvbPmtSectionEntry entry = section.entries(); entry.isValid(); entry.advance()) {
 		QString streamLanguage;
 		QString subtitleLanguage;
+		QString fourcc;
 		bool teletextPresent = false;
-		bool ac3Present = false;
+		bool audioPresent = false;
+		bool videoPresent = false;
 
 		for (DvbDescriptor descriptor = entry.descriptors(); descriptor.isValid();
 		     descriptor.advance()) {
 			switch (descriptor.descriptorTag()) {
+			case 0x05: {
+				DvbRegistrationDescriptor registrationDescriptor(descriptor);
+				fourcc.clear();
+				fourcc.append(QChar(registrationDescriptor.formatIdentifier0()));
+				fourcc.append(QChar(registrationDescriptor.formatIdentifier1()));
+				fourcc.append(QChar(registrationDescriptor.formatIdentifier2()));
+				fourcc.append(QChar(registrationDescriptor.formatIdentifier3()));
+
+				/* Handle audio and video fourcc's */
+				if (entry.streamType() == 0x06 &&
+				    (fourcc == "EAC3" ||
+				     fourcc == "AC-3" ||
+				     fourcc == "DTS1" ||
+				     fourcc == "DTS2" ||
+				     fourcc == "DTS3" ||
+				     fourcc == "BSSD"))
+					audioPresent = true;
+				else if ((entry.streamType() == 0x06 && fourcc == "HEVC") ||
+					 (entry.streamType() == 0xea && fourcc == "VC-1"))
+					videoPresent = true;
+				break;
+			    }
+
 			case 0x0a: {
 				DvbLanguageDescriptor languageDescriptor(descriptor);
 
@@ -1207,11 +1232,24 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 
 			case 0x6a:
 			case 0x7a:
-				ac3Present = true;
+				audioPresent = true;
 				break;
 			}
 		}
 
+		/*
+		 * The code above already checks for streamType. So,
+		 * once we add a video channel here, just rely on it,
+		 * without parsing the streamType() again.
+		 */
+		if (videoPresent) {
+			if (videoPid < 0) {
+				videoPid = entry.pid();
+			} else {
+				qCInfo(logDvbSi, "More than one video PID");
+			}
+			continue;
+		}
 
 		// Updated with Table 2-34 of ISO/IEC 13818-1:2018 / ITU-T H.222.0 2017
 		// and with https://www.wikiwand.com/en/Program-specific_information
@@ -1285,7 +1323,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				}
 			}
 
-			if (ac3Present) {
+			if (audioPresent) {
 				audioPids.append(qMakePair(entry.pid(), streamLanguage));
 			}
 
@@ -1505,6 +1543,15 @@ void AtscVctSectionEntry::initVctSectionEntry(const char *data, int size)
 	initSectionData(data, entryLength, size);
 }
 
+DvbRegistrationDescriptor::DvbRegistrationDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 6) {
+		qCWarning(logDvbSi, "Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
 DvbLanguageDescriptor::DvbLanguageDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 6) {
@@ -1763,3 +1810,5 @@ void AtscEttSection::initEttSection(const char *data, int size)
 
 	initStandardSection(data, size);
 }
+
+#include "moc_dvbsi.cpp"
