@@ -20,6 +20,8 @@
 
 #include <QDataStream>
 #include <QTextStream>
+#include <QString>
+
 #include <stdint.h>
 
 #include "dvbtransponder.h"
@@ -733,7 +735,7 @@ void IsdbTTransponder::readTransponder(QDataStream &stream)
 
 	stream >> layers;
 	for (int i = 0; i < 3; i ++) {
-		if ((1 << i) && layers)
+		if ((1 << i) & layers)
 			layerEnabled[i] = true;
 		else
 			layerEnabled[i] = false;
@@ -743,6 +745,18 @@ void IsdbTTransponder::readTransponder(QDataStream &stream)
 		stream >> segmentCount[i];
 		interleaving[i] = readEnum<Interleaving>(stream);
 	}
+
+	// Sanity check: if no labels are enabled, enable them all
+	if (!(layers & 7)) {
+		layers = 7;
+		for (int i = 0; i < 3; i ++) {
+			layerEnabled[i] = true;
+			modulation[i] = IsdbTTransponder::ModulationAuto;
+			fecRate[i] = IsdbTTransponder::FecAuto;
+			interleaving[i] = IsdbTTransponder::I_AUTO;
+			segmentCount[i] = 15;
+		}
+	}
 }
 
 bool IsdbTTransponder::fromString(const QString &string)
@@ -762,7 +776,7 @@ bool IsdbTTransponder::fromString(const QString &string)
 
 	reader.readInt(layers);
 	for (int i = 0; i < 3; i ++) {
-		if ((1 << i) && layers)
+		if ((1 << i) & layers)
 			layerEnabled[i] = true;
 		else
 			layerEnabled[i] = false;
@@ -773,6 +787,18 @@ bool IsdbTTransponder::fromString(const QString &string)
 		interleaving[i] = reader.readEnum<Interleaving>();
 	}
 
+	// Sanity check: if no labels are enabled, enable them all
+	if (!(layers & 7)) {
+		layers = 7;
+		for (int i = 0; i < 3; i ++) {
+			layerEnabled[i] = true;
+			modulation[i] = IsdbTTransponder::ModulationAuto;
+			fecRate[i] = IsdbTTransponder::FecAuto;
+			interleaving[i] = IsdbTTransponder::I_AUTO;
+			segmentCount[i] = 15;
+		}
+	}
+
 	return reader.isValid();
 }
 
