@@ -44,7 +44,7 @@ XmlTv::XmlTv(DvbManager *manager_) : manager(manager_), r(NULL)
 
 void XmlTv::addFile(QString file)
 {
-	if (file == "")
+	if (file.isEmpty())
 		return;
 
 	load(file);
@@ -104,10 +104,10 @@ bool XmlTv::parseChannel(void)
 			continue;
 
 		QStringRef name = r->name();
-		if (name == "display-name") {
+		if (name == QLatin1String("display-name")) {
 			QString display = r->readElementText();
 			list.append(display);
-		} else if (name != "icon" && name != "url") {
+		} else if (name != QLatin1String("icon") && name != QLatin1String("url")) {
 			static QString lastNotFound("");
 			if (name.toString() != lastNotFound) {
 				qCWarning(logDvb,
@@ -209,7 +209,7 @@ QString XmlTv::parseCredits(void)
 		value += r->readElementText();
 
 		if (key == "actor") {
-			value += i18n(" as ") + attrs.value("role").toString();
+			value = i18nc("%1 is a person; %2 is their character", "%1 as %2", value, attrs.value("role").toString());
 		}
 
 		keyValues.insert(key, value);
@@ -241,7 +241,7 @@ QString XmlTv::parseCredits(void)
 		else
 			name = key + "(s)";
 
-		values += name + ": " + keyValues.value(key) + "\n";
+		values += i18nc("%1 is a role (actor, director, etc); %2 is one or more people", "%1: %2\n", name, keyValues.value(key));
 	}
 
 	return values;
@@ -268,7 +268,7 @@ bool XmlTv::parseProgram(void)
 	QList<QString>::iterator name;
 	bool has_channel = false;
 
-	for (name = list.begin(); name != list.end(); name++) {
+	for (name = list.begin(); name != list.end(); ++name) {
 		if (channelModel->hasChannelByName(*name)) {
 			has_channel = true;
 			break;
@@ -335,28 +335,28 @@ bool XmlTv::parseProgram(void)
 
 		QString lang;
 		QStringRef element = r->name();
-		if (element == "title") {
+		if (element == QLatin1String("title")) {
 			attrs = r->attributes();
 			lang = IsoCodes::code2Convert(attrs.value("lang").toString());
 			langEntry = getLangEntry(epgEntry, lang);
-			if (langEntry->title != "")
-				langEntry->title += " ";
+			if (!langEntry->title.isEmpty())
+				langEntry->title += ' ';
 			langEntry->title += r->readElementText();
-		} else if (element == "sub-title") {
+		} else if (element == QLatin1String("sub-title")) {
 			attrs = r->attributes();
 			lang = IsoCodes::code2Convert(attrs.value("lang").toString());
 			langEntry = getLangEntry(epgEntry, lang);
-			if (langEntry->subheading != "")
-				langEntry->subheading += " ";
+			if (!langEntry->subheading.isEmpty())
+				langEntry->subheading += ' ';
 			langEntry->subheading += r->readElementText();
-		} else if (element == "desc") {
+		} else if (element == QLatin1String("desc")) {
 			attrs = r->attributes();
 			lang = IsoCodes::code2Convert(attrs.value("lang").toString());
 			langEntry = getLangEntry(epgEntry, lang);
-			if (langEntry->details != "")
-				langEntry->details += " ";
+			if (!langEntry->details.isEmpty())
+				langEntry->details += ' ';
 			langEntry->details += r->readElementText();
-		} else if (element == "rating") {
+		} else if (element == QLatin1String("rating")) {
 			QHash<QString, QString> keyValues;
 
 			attrs = r->attributes();
@@ -365,17 +365,17 @@ bool XmlTv::parseProgram(void)
 			parseKeyValues(keyValues);
 			QString value = getValue(keyValues, "value");
 
-			if (value == "")
+			if (value.isEmpty())
 				continue;
 
-			if (epgEntry.parental != "")
+			if (!epgEntry.parental.isEmpty())
 				epgEntry.parental += ", ";
 
-			if (system != "")
-				epgEntry.parental += system + " ";
+			if (!system.isEmpty())
+				epgEntry.parental += system + ' ';
 
-			epgEntry.parental += i18n("rating: ") + value;
-		} else if (element == "star-rating") {
+			epgEntry.parental += i18n("rating: %1", value);
+		} else if (element == QLatin1String("star-rating")) {
 			QHash<QString, QString> keyValues;
 
 			attrs = r->attributes();
@@ -384,58 +384,58 @@ bool XmlTv::parseProgram(void)
 			parseKeyValues(keyValues);
 			QString value = getValue(keyValues, "value");
 
-			if (value == "")
+			if (value.isEmpty())
 				continue;
 
-			if (system != "")
-				starRating += system + " ";
+			if (!system.isEmpty())
+				starRating += system + ' ';
 
 			starRating += value;
-		} else if (element == "category") {
+		} else if (element == QLatin1String("category")) {
 			attrs = r->attributes();
 			lang = IsoCodes::code2Convert(attrs.value("lang").toString());
 
 			QString cat = getValue(category, lang);
-			if (cat != "")
+			if (!cat.isEmpty())
 				cat += ", ";
 			cat += r->readElementText();
 			category[lang] = cat;
-		} else if (element == "keyword") {
+		} else if (element == QLatin1String("keyword")) {
 			attrs = r->attributes();
 			lang = IsoCodes::code2Convert(attrs.value("lang").toString());
 
 			QString kw = getValue(keyword, lang);
-			if (kw != "")
+			if (!kw.isEmpty())
 				kw += ", ";
 			kw += r->readElementText();
 			keyword[lang] = kw;
-		} else if (element == "credits") {
+		} else if (element == QLatin1String("credits")) {
 			credits = parseCredits();
-		} else if ((element == "date")) {
+		} else if ((element == QLatin1String("date"))) {
 			QString rawdate = r->readElementText();
 			date = rawdate.mid(0, 4);
 			QString month = rawdate.mid(4, 2);
 			QString day = rawdate.mid(6, 2);
-			if (month != "")
-				date += "-" + month;
-			if (day != "") {
-				date += "-" + day;
+			if (!month.isEmpty())
+				date += '-' + month;
+			if (!day.isEmpty()) {
+				date += '-' + day;
 				QDate d = QDate::fromString(date, Qt::ISODate);
-				date = d.toString(Qt::DefaultLocaleShortDate);
+				date = QLocale().toString(d, QLocale::ShortFormat);
 			}
-		} else if (element == "language") {
+		} else if (element == QLatin1String("language")) {
 			language = r->readElementText();
 			if (language.size() == 2)
 				IsoCodes::getLanguage(IsoCodes::code2Convert(language), &language);
-		} else if (element == "orig-language") {
+		} else if (element == QLatin1String("orig-language")) {
 			origLanguage = r->readElementText();
 			if (origLanguage.size() == 2)
 				IsoCodes::getLanguage(IsoCodes::code2Convert(origLanguage), &origLanguage);
-		} else if (element == "country") {
+		} else if (element == QLatin1String("country")) {
 			country = r->readElementText();
 			if (origLanguage.size() == 2)
 				IsoCodes::getCountry(IsoCodes::code2Convert(country), &country);
-		} else if (element == "episode-num") {
+		} else if (element == QLatin1String("episode-num")) {
 			attrs = r->attributes();
 			QString system = attrs.value("system").toString();
 
@@ -443,29 +443,29 @@ bool XmlTv::parseProgram(void)
 				continue;
 
 			episode = r->readElementText();
-			episode.remove(" ");
-			episode.replace(QRegularExpression("/.*"), "");
-			QStringList list = episode.split(".");
+			episode.remove(' ');
+			episode.remove(QRegularExpression("/.*"));
+			QStringList list = episode.split('.');
 			if (!list.size())
 				continue;
-			episode = i18n("Season ") + QString::number(list[0].toInt() + 1);
+			episode = i18n("Season %1", QString::number(list[0].toInt() + 1));
 			if (list.size() < 2)
 				continue;
-			episode += i18n(" Episode ") + QString::number(list[1].toInt() + 1);
-		} else if ((element == "aspect") ||
-			   (element == "audio") ||
-			   (element == "icon") ||
-			   (element == "length") ||
-			   (element == "last-chance") ||
-			   (element == "new") ||
-			   (element == "premiere") ||
-			   (element == "previously-shown") ||
-			   (element == "quality") ||
-			   (element == "review") ||
-			   (element == "stereo") ||
-			   (element == "subtitles") ||
-			   (element == "url") ||
-			   (element == "video")) {
+			episode += i18n(" Episode %1", QString::number(list[1].toInt() + 1));
+		} else if ((element == QLatin1String("aspect")) ||
+			   (element == QLatin1String("audio")) ||
+			   (element == QLatin1String("icon")) ||
+			   (element == QLatin1String("length")) ||
+			   (element == QLatin1String("last-chance")) ||
+			   (element == QLatin1String("new")) ||
+			   (element == QLatin1String("premiere")) ||
+			   (element == QLatin1String("previously-shown")) ||
+			   (element == QLatin1String("quality")) ||
+			   (element == QLatin1String("review")) ||
+			   (element == QLatin1String("stereo")) ||
+			   (element == QLatin1String("subtitles")) ||
+			   (element == QLatin1String("url")) ||
+			   (element == QLatin1String("video"))) {
 			ignoreTag();
 		} else {
 			static QString lastNotFound("");
@@ -479,26 +479,26 @@ bool XmlTv::parseProgram(void)
 	}
 
 	/* Those extra fields are not language-specific data */
-	if (starRating != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
-		epgEntry.content += i18n("Star rating: ") + starRating;
+	if (!starRating.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
+		epgEntry.content += i18n("Star rating: %1", starRating);
 	}
 
-	if (date != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
-		epgEntry.content += i18n("Date: ") + date;
+	if (!date.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
+		epgEntry.content += i18n("Date: %1", date);
 	}
 
 	foreach(const QString &key, category.keys()) {
-		QString value = i18n("Category: ") + category[key];
+		QString value = i18n("Category: %1", category[key]);
 		QString lang = key;
 		if (key != "QAA")
 			langEntry = getLangEntry(epgEntry, lang, false);
 		if (!langEntry) {
-			if (epgEntry.content != "")
-				epgEntry.content += "\n";
+			if (!epgEntry.content.isEmpty())
+				epgEntry.content += '\n';
 			epgEntry.content += value;
 		} else {
 			langEntry->details.replace(QRegularExpression("\\n*$"), "<p/>");
@@ -506,13 +506,13 @@ bool XmlTv::parseProgram(void)
 		}
 	}
 	foreach(const QString &key, keyword.keys()) {
-		QString value = i18n("Keyword: ") + keyword[key];
+		QString value = i18n("Keyword: %1", keyword[key]);
 		QString lang = key;
 		if (key != "QAA")
 			langEntry = getLangEntry(epgEntry, lang, false);
 		if (!langEntry) {
-			if (epgEntry.content != "")
-				epgEntry.content += "\n";
+			if (!epgEntry.content.isEmpty())
+				epgEntry.content += '\n';
 			epgEntry.content += value;
 		} else {
 			langEntry->details.replace(QRegularExpression("\\n*$"), "<p/>");
@@ -520,33 +520,33 @@ bool XmlTv::parseProgram(void)
 		}
 	}
 
-	if (episode != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
-		epgEntry.content += i18n("language: ") + episode;
+	if (!episode.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
+		epgEntry.content += i18n("language: %1", episode);
 	}
 
-	if (language != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
-		epgEntry.content += i18n("language: ") + language;
+	if (!language.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
+		epgEntry.content += i18n("language: %1", language);
 	}
 
-	if (origLanguage != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
-		epgEntry.content += i18n("Original language: ") + origLanguage;
+	if (!origLanguage.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
+		epgEntry.content += i18n("Original language: %1", origLanguage);
 	}
 
-	if (country != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
-		epgEntry.content += i18n("Country: ") + country;
+	if (!country.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
+		epgEntry.content += i18n("Country: %1", country);
 	}
 
-	if (credits != "") {
-		if (epgEntry.content != "")
-			epgEntry.content += "\n";
+	if (!credits.isEmpty()) {
+		if (!epgEntry.content.isEmpty())
+			epgEntry.content += '\n';
 		epgEntry.content += credits;
 	}
 
@@ -600,13 +600,13 @@ bool XmlTv::load(QString file)
 
 		QStringRef name = r->name();
 
-		if (name == "channel") {
+		if (name == QLatin1String("channel")) {
 			if (!parseChannel())
 				parseError = true;
-		} else if (name == "programme") {
+		} else if (name == QLatin1String("programme")) {
 			if (!parseProgram())
 				parseError = true;
-		} else if (name != "tv") {
+		} else if (name != QLatin1String("tv")) {
 			static QString lastNotFound("");
 			if (name.toString() != lastNotFound) {
 				qCWarning(logDvb,
@@ -630,3 +630,5 @@ bool XmlTv::load(QString file)
 	watcher.addPath(file);
 	return parseError;
 }
+
+#include "moc_xmltv.cpp"
