@@ -18,12 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <KLocalizedString>
-#include <QDebug>
-#if QT_VERSION < 0x050500
-# define qInfo qDebug
-#endif
-
+#include "log.h"
 #include "ensurenopendingoperation.h"
 
 void EnsureNoPendingOperation::printFatalErrorMessage()
