@@ -32,6 +32,8 @@
 #include <QStandardPaths>
 #include <QString>
 
+#include <kwindowsystem_version.h>
+
 #include <iostream>
 
 #include <config-kaffeine.h>
@@ -142,10 +144,10 @@ KaffeineApplication::KaffeineApplication(int &argc, char **argv) : QApplication(
 		// Optional additional text
 		"",
 		// Home page
-		QStringLiteral("http://kaffeine.kde.org")
+		QStringLiteral("https://kde.org/applications/multimedia/org.kde.kaffeine")
 	)
 {
-	QString path = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+	QString path = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
 
 	QDir dir(path);
 	if (!dir.exists())
@@ -176,12 +178,19 @@ KaffeineApplication::KaffeineApplication(int &argc, char **argv) : QApplication(
 void KaffeineApplication::activateRequested(const QStringList &arguments,
 					    const QString &workingDirectory)
 {
-	if (arguments.isEmpty())
-		return;
-
 	parser.parse(arguments);
+
+#if KWINDOWSYSTEM_VERSION > QT_VERSION_CHECK(5, 91, 0)
+	KWindowSystem::updateStartupId(mainWindow->windowHandle());
+	KWindowSystem::activateWindow(mainWindow->windowHandle());
+#else
+#if KWINDOWSYSTEM_VERSION  >= QT_VERSION_CHECK(5, 62, 0)
+	KStartupInfo::setNewStartupId(mainWindow->window()->windowHandle(), KStartupInfo::startupId());
+#else
 	KStartupInfo::setNewStartupId(mainWindow, KStartupInfo::startupId());
+#endif
 	KWindowSystem::forceActiveWindow(mainWindow->winId());
+#endif
 	mainWindow->parseArgs(workingDirectory);
 }
 
@@ -209,7 +218,6 @@ int main(int argc, char *argv[])
 	app.setApplicationName("kaffeine");
 	app.setOrganizationDomain("kde.org");
 	app.setWindowIcon(QIcon::fromTheme(QLatin1String("kaffeine"), QIcon(":kaffeine")));
-	app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
 	app.parser.addVersionOption();
 	app.parser.addHelpOption();
