@@ -75,7 +75,7 @@ public:
 	explicit StackedLayout(QWidget *parent) : QStackedLayout(parent) { }
 	~StackedLayout() { }
 
-	QSize minimumSize() const
+	QSize minimumSize() const override
 	{
 		QWidget *widget = currentWidget();
 
@@ -94,7 +94,7 @@ public:
 	~StartTab() { }
 
 private:
-	void activate() { }
+	void activate() override { }
 
 	QAbstractButton *addShortcut(const QString &name, const QIcon &icon, QWidget *parent);
 };
@@ -106,7 +106,7 @@ StartTab::StartTab(MainWindow *mainWindow)
 
 	QGridLayout *gridLayout = new QGridLayout(this);
 	gridLayout->setAlignment(Qt::AlignCenter);
-	gridLayout->setMargin(10);
+	gridLayout->setContentsMargins(10, 10, 10, 10);
 	gridLayout->setSpacing(15);
 
 	QAbstractButton *button =
@@ -162,7 +162,7 @@ public:
 	explicit PlayerTab(MediaWidget *mediaWidget_);
 	~PlayerTab() { }
 
-	void activate()
+	void activate() override
 	{
 		layout()->addWidget(mediaWidget);
 		mediaWidget->setFocus();
@@ -175,7 +175,7 @@ private:
 PlayerTab::PlayerTab(MediaWidget *mediaWidget_) : mediaWidget(mediaWidget_)
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 }
 
 void MainWindow::run()
@@ -387,8 +387,10 @@ void MainWindow::run()
 	// workaround setAutoSaveSettings() which doesn't accept "IconOnly" as initial state
 	controlBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
 
+#if QT_VERSION < 0x050a00
 	// initialize random number generator
 	qsrand(QTime(0, 0, 0).msecsTo(QTime::currentTime()));
+#endif
 
 	// initialize dbus objects
 	QDBusConnection::sessionBus().registerObject(QLatin1String("/"), new MprisRootObject(this),
@@ -450,6 +452,7 @@ void MainWindow::readSettings()
     QSettings settings(QCoreApplication::organizationName(), QCoreApplication::applicationName());
     const QByteArray geometry = settings.value("geometry", QByteArray()).toByteArray();
     if (geometry.isEmpty()) {
+        winId(); // force creation of windowHandle()
         const QRect availableGeometry = QApplication::desktop()->availableGeometry(this);
         resize(availableGeometry.width() / 3, availableGeometry.height() / 2);
         move((availableGeometry.width() - width()) / 2,
@@ -788,7 +791,8 @@ void MainWindow::playDvb()
 
 void MainWindow::configureKeys()
 {
-	KShortcutsDialog::configure(collection);
+	shortcuts = new KShortcutsDialog(this);
+	shortcuts->addCollection(collection);
 }
 
 void MainWindow::configureKaffeine()
@@ -909,3 +913,5 @@ void MainWindow::leaveEvent(QEvent *event)
 
 	QMainWindow::leaveEvent(event);
 }
+
+#include "moc_mainwindow.cpp"
