@@ -40,10 +40,11 @@
 #include <QTimeEdit>
 #include <QTimer>
 #include <QWidgetAction>
-#include <QX11Info>
+#include <QActionGroup>
+
 #include <Solid/Block>
 #include <Solid/Device>
-#include <X11/extensions/scrnsaver.h>
+#include <KWindowSystem>
 
 #include "backend-vlc/vlcmediawidget.h"
 #include "configuration.h"
@@ -51,6 +52,11 @@
 #include "mediawidget_p.h"
 #include "osdwidget.h"
 
+// Needs to be included before X11 headers, which deine some things like "Bool"
+#include "moc_mediawidget.cpp"
+
+#include <X11/extensions/scrnsaver.h>
+
 MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *collection,
 	QWidget *parent) : QWidget(parent), menu(menu_), displayMode(NormalMode),
 	autoResizeFactor(0), blockBackendUpdates(false), muted(false),
@@ -60,7 +66,7 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 	source = dummySource.data();
 
 	QBoxLayout *layout = new QVBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 
 	QPalette palette = QWidget::palette();
 	palette.setColor(backgroundRole(), Qt::black);
@@ -441,7 +447,7 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 	jumpToPositionAction = new QWidgetAction(this);
 	jumpToPositionAction->setIcon(QIcon::fromTheme(QLatin1String("go-jump"), QIcon(":go-jump")));
 	jumpToPositionAction->setText(i18nc("@action:inmenu", "Jump to Position..."));
-	jumpToPositionAction->setShortcut(Qt::CTRL + Qt::Key_J);
+	jumpToPositionAction->setShortcut(Qt::CTRL | Qt::Key_J);
 	connect(jumpToPositionAction, SIGNAL(triggered()), this, SLOT(jumpToPosition()));
 	menu->addAction(collection->addAction(QLatin1String("controls_jump_to_position"), jumpToPositionAction));
 
@@ -460,7 +466,7 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 	longSkipBackwardAction->setIcon(QIcon::fromTheme(QLatin1String("media-skip-backward"), QIcon(":media-skip-backward")));
 	// xgettext:no-c-format
 	longSkipBackwardAction->setText(i18nc("submenu of 'Skip'", "Skip %1s Backward", longSkipDuration));
-	longSkipBackwardAction->setShortcut(Qt::SHIFT + Qt::Key_Left);
+	longSkipBackwardAction->setShortcut(Qt::SHIFT | Qt::Key_Left);
 	connect(longSkipBackwardAction, SIGNAL(triggered()), this, SLOT(longSkipBackward()));
 	navigationMenu->addAction(
 		collection->addAction(QLatin1String("controls_long_skip_backward"), longSkipBackwardAction));
@@ -487,7 +493,7 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 	longSkipForwardAction->setIcon(QIcon::fromTheme(QLatin1String("media-skip-forward"), QIcon(":media-skip-forward")));
 	// xgettext:no-c-format
 	longSkipForwardAction->setText(i18nc("submenu of 'Skip'", "Skip %1s Forward", longSkipDuration));
-	longSkipForwardAction->setShortcut(Qt::SHIFT + Qt::Key_Right);
+	longSkipForwardAction->setShortcut(Qt::SHIFT | Qt::Key_Right);
 	connect(longSkipForwardAction, SIGNAL(triggered()), this, SLOT(longSkipForward()));
 	navigationMenu->addAction(
 		collection->addAction(QLatin1String("controls_long_skip_forward"), longSkipForwardAction));
@@ -547,6 +553,9 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 
 MediaWidget::~MediaWidget()
 {
+	// Ensure that the screen saver will be disabled
+	checkScreenSaver(true);
+
 	KSharedConfig::openConfig()->group("MediaObject").writeEntry("Volume", volumeSlider->value());
 	KSharedConfig::openConfig()->group("MediaObject").writeEntry("Deinterlace", deinterlaceMode);
 	KSharedConfig::openConfig()->group("MediaObject").writeEntry("AutoResizeFactor", autoResizeFactor);
@@ -834,17 +843,19 @@ void MediaWidget::decreaseVolume()
 	volumeSlider->setValue(volumeSlider->value() - 5);
 }
 
-void MediaWidget::checkScreenSaver()
+void MediaWidget::checkScreenSaver(bool noDisable)
 {
 	bool suspendScreenSaver = false;
 
-	switch (backend->getPlaybackStatus()) {
-	case Idle:
-	case Paused:
-		break;
-	case Playing:
-		suspendScreenSaver = isVisible();
-		break;
+	if (!noDisable) {
+		switch (backend->getPlaybackStatus()) {
+		case Idle:
+		case Paused:
+			break;
+		case Playing:
+			suspendScreenSaver = isVisible();
+			break;
+		}
 	}
 
 	if (suspendScreenSaver) {
@@ -858,12 +869,6 @@ void MediaWidget::checkScreenSaver()
 			       QLatin1String("org.gnome.ScreenSaver")).
 			call(QDBus::NoBlock, QLatin1String("SimulateUserActivity"));
 	}
-
-	if (screenSaverSuspended != suspendScreenSaver) {
-		// X11 - needed if none of the above applications is running
-		screenSaverSuspended = suspendScreenSaver;
-		XScreenSaverSuspend(QX11Info::display(), suspendScreenSaver);
-	}
 }
 
 void MediaWidget::mutedChanged()
@@ -1359,7 +1364,7 @@ void MediaWidget::resizeEvent(QResizeEvent *event)
 
 void MediaWidget::wheelEvent(QWheelEvent *event)
 {
-	int y = event->delta();
+	int y = event->angleDelta().y();
 	int delta = (y < 0) ? -1 : 1;
 
 	setVolumeUnderMouse(getVolume() + delta);
@@ -1614,7 +1619,7 @@ void SeekSlider::mousePressEvent(QMouseEvent *event)
 
 void SeekSlider::wheelEvent(QWheelEvent *event)
 {
-	int delta = (event->delta() < 0) ? -1 : 1;
+	int delta = (event->angleDelta().y() < 0) ? -1 : 1;
 	int new_value = value() + delta * maximum() / 100;
 
 	event->accept();
