@@ -247,7 +247,6 @@ bool Playlist::loadKaffeinePlaylist(QIODevice *device)
 bool Playlist::loadM3UPlaylist(QIODevice *device)
 {
 	QTextStream stream(device);
-	stream.setCodec("UTF-8");
 	PlaylistTrack track;
 
 	while (!stream.atEnd()) {
@@ -278,7 +277,6 @@ bool Playlist::loadM3UPlaylist(QIODevice *device)
 void Playlist::saveM3UPlaylist(QIODevice *device) const
 {
 	QTextStream stream(device);
-	stream.setCodec("UTF-8");
 	stream << "#EXTM3U\n";
 
 	foreach (const PlaylistTrack &track, tracks) {
@@ -296,7 +294,6 @@ void Playlist::saveM3UPlaylist(QIODevice *device) const
 bool Playlist::loadPLSPlaylist(QIODevice *device)
 {
 	QTextStream stream(device);
-	stream.setCodec("UTF-8");
 
 	if (stream.readLine().compare(QLatin1String("[playlist]"), Qt::CaseInsensitive) != 0) {
 		return false;
@@ -366,7 +363,6 @@ bool Playlist::loadPLSPlaylist(QIODevice *device)
 void Playlist::savePLSPlaylist(QIODevice *device) const
 {
 	QTextStream stream(device);
-	stream.setCodec("UTF-8");
 	stream << "[Playlist]\n"
 		"NumberOfEntries=" << tracks.size() << '\n';
 	int index = 1;
@@ -881,8 +877,8 @@ void PlaylistModel::sort(int column, Qt::SortOrder order)
 		mapping[i] = i;
 	}
 
-	qSort(mapping.begin(), mapping.end(),
-		PlaylistTrackLessThan(visiblePlaylist, column, order));
+	std::sort(mapping.begin(), mapping.end(),
+		  PlaylistTrackLessThan(visiblePlaylist, column, order));
 
 	QVector<int> reverseMapping(mapping.size());
 
@@ -897,7 +893,11 @@ void PlaylistModel::sort(int column, Qt::SortOrder order)
 
 		if (i != target) {
 			qSwap(mapping[i], mapping[target]);
+#if QT_VERSION < 0x050c00
 			visiblePlaylist->tracks.swap(i, target);
+#else
+			visiblePlaylist->tracks.swapItemsAt(i, target);
+#endif
 		} else {
 			++i;
 		}
@@ -995,3 +995,5 @@ bool PlaylistModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
 
 	return false;
 }
+
+#include "moc_playlistmodel.cpp"
