@@ -33,6 +33,10 @@
 #include <QTimer>
 #include <QToolButton>
 
+#if QT_VERSION >= 0x050a00
+#  include <QRandomGenerator>
+#endif
+
 #include "playlistmodel.h"
 #include "playlisttab.h"
 
@@ -42,10 +46,10 @@ PlaylistBrowserModel::PlaylistBrowserModel(PlaylistModel *playlistModel_,
 {
 	playlists.append(temporaryPlaylist);
 
-	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/playlistsK4"));
+	QFile file(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + QLatin1String("/playlistsK4"));
 
 	if (!file.open(QIODevice::ReadOnly)) {
-		file.setFileName(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/playlists"));
+		file.setFileName(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + QLatin1String("/playlists"));
 
 		if (!file.open(QIODevice::ReadOnly)) {
 			qCWarning(logPlaylist, "Cannot open file %s", qPrintable(file.fileName()));
@@ -123,7 +127,7 @@ PlaylistBrowserModel::PlaylistBrowserModel(PlaylistModel *playlistModel_,
 
 PlaylistBrowserModel::~PlaylistBrowserModel()
 {
-	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/playlistsK4"));
+	QFile file(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + QLatin1String("/playlistsK4"));
 
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
 		qCWarning(logPlaylist, "Cannot open file %s", qPrintable(file.fileName()));
@@ -303,14 +307,14 @@ public:
 	~PlaylistBrowserView() { }
 
 protected:
-	void keyPressEvent(QKeyEvent *event);
+	void keyPressEvent(QKeyEvent *event) override;
 };
 
 void PlaylistBrowserView::keyPressEvent(QKeyEvent *event)
 {
 	if (event->key() == Qt::Key_Delete) {
 		QModelIndexList selectedRows = selectionModel()->selectedRows();
-		qSort(selectedRows);
+		std::sort(selectedRows.begin(), selectedRows.end());
 
 		for (int i = selectedRows.size() - 1; i >= 0; --i) {
 			// FIXME compress
@@ -334,7 +338,7 @@ PlaylistView::~PlaylistView()
 void PlaylistView::removeSelectedRows()
 {
 	QModelIndexList selectedRows = selectionModel()->selectedRows();
-	qSort(selectedRows);
+	std::sort(selectedRows.begin(), selectedRows.end());
 
 	for (int i = selectedRows.size() - 1; i >= 0; --i) {
 		// FIXME compress
@@ -435,7 +439,7 @@ PlaylistTab::PlaylistTab(QMenu *menu, KActionCollection *collection, MediaWidget
 	menu->addAction(collection->addAction(QLatin1String("playlist_save_as"), savePlaylistAsAction));
 
 	QBoxLayout *widgetLayout = new QHBoxLayout(this);
-	widgetLayout->setMargin(0);
+	widgetLayout->setContentsMargins(0, 0, 0, 0);
 
 	QSplitter *horizontalSplitter = new QSplitter(this);
 	widgetLayout->addWidget(horizontalSplitter);
@@ -444,7 +448,7 @@ PlaylistTab::PlaylistTab(QMenu *menu, KActionCollection *collection, MediaWidget
 
 	QWidget *widget = new QWidget(verticalSplitter);
 	QBoxLayout *sideLayout = new QVBoxLayout(widget);
-	sideLayout->setMargin(0);
+	sideLayout->setContentsMargins(0, 0, 0, 0);
 
 	QBoxLayout *boxLayout = new QHBoxLayout();
 
@@ -497,7 +501,7 @@ PlaylistTab::PlaylistTab(QMenu *menu, KActionCollection *collection, MediaWidget
 
 	widget = new QWidget(verticalSplitter);
 	sideLayout = new QVBoxLayout(widget);
-	sideLayout->setMargin(0);
+	sideLayout->setContentsMargins(0, 0, 0, 0);
 
 	boxLayout = new QHBoxLayout();
 
@@ -543,7 +547,7 @@ PlaylistTab::PlaylistTab(QMenu *menu, KActionCollection *collection, MediaWidget
 
 	QWidget *mediaContainer = new QWidget(verticalSplitter);
 	mediaLayout = new QHBoxLayout(mediaContainer);
-	mediaLayout->setMargin(0);
+	mediaLayout->setContentsMargins(0, 0, 0, 0);
 
 	verticalSplitter->setStretchFactor(1, 1);
 	horizontalSplitter->setStretchFactor(1, 1);
@@ -645,7 +649,7 @@ void PlaylistTab::renamePlaylist()
 void PlaylistTab::removePlaylist()
 {
 	QModelIndexList selectedRows = playlistBrowserView->selectionModel()->selectedRows();
-	qSort(selectedRows);
+	std::sort(selectedRows.begin(), selectedRows.end());
 
 	for (int i = selectedRows.size() - 1; i >= 0; --i) {
 		// FIXME compress
@@ -722,7 +726,12 @@ void PlaylistTab::playNextTrack()
 		if (size < 2) {
 			playTrack(currentPlaylist, 0);
 		} else if (currentPlaylist->currentTrack != -1) {
-			int track = (qrand() % (size - 1));
+#if QT_VERSION >= 0x050a00
+			quint32 rand = QRandomGenerator::global()->generate();
+#else
+			quint32 rand = qrand();
+#endif
+			int track = (rand % (size - 1));
 
 			if (track >= currentPlaylist->currentTrack) {
 				++track;
@@ -730,7 +739,12 @@ void PlaylistTab::playNextTrack()
 
 			playTrack(currentPlaylist, track);
 		} else {
-			playTrack(currentPlaylist, qrand() % size);
+#if QT_VERSION >= 0x050a00
+			quint32 rand = QRandomGenerator::global()->generate();
+#else
+			quint32 rand = qrand();
+#endif
+			playTrack(currentPlaylist, rand % size);
 		}
 	} else if (((currentPlaylist->currentTrack + 1) == currentPlaylist->tracks.size()) &&
 		   repeatAction->isChecked()) {
@@ -872,3 +886,5 @@ void PlaylistTab::savePlaylist(bool askName)
 		playlist->save(format);
 	}
 }
+
+#include "moc_playlisttab.cpp"
