@@ -56,7 +56,7 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	qSort(paths);
+	std::sort(paths.begin(), paths.end());
 
 	foreach (const QString &path, paths) {
 		QFile file(path);
@@ -88,7 +88,7 @@ int main(int argc, char *argv[])
 		// FIXME make src/scanfile.dvb ascii-only
 
 		if ((path == "README") || (path == "src/scanfile.dvb") ||
-		    path.endsWith(".desktop")) {
+		    path.endsWith(QLatin1String(".desktop"))) {
 			continue;
 		}
 
